package App::Greple;

use strict;
use warnings;

=head1 NAME

greple - extensible grep with lexical expression and region handling

=head1 VERSION

Version 9.04

=cut

our $VERSION = '9.04';

=head1 AUTHOR

Kazumasa Utashiro

=head1 LICENSE AND COPYRIGHT

Copyright 1991-2023 Kazumasa Utashiro

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1; # End of App::Greple
